package com.mdtexfx.processors;

import com.mdtexfx.html.HtmlRenderer;
import com.mdtexfx.io.MediaType;
import com.mdtexfx.processors.highlighters.PlaintextHighlighter;
import com.mdtexfx.processors.highlighters.SyntaxHighlighter;

/**
 * Responsible for bundling components that the {@link ProcessorFactory}
 * requires to create all {@link Processor} chains.
 */
public class ProcessorContext {
  private final MediaType mMediaType;
  private final HtmlRenderer mHtmlRenderer;
  private final SyntaxHighlighter mHighlighter;

  /**
   * Constructs a context used by the {@link ProcessorFactory} having a default
   * syntax highlighter of {@link PlaintextHighlighter}.
   *
   * @param mediaType    The {@link MediaType} that directs transformations.
   * @param htmlRenderer Where to write the output HTML.
   */
  public ProcessorContext(
      final MediaType mediaType, final HtmlRenderer htmlRenderer ) {
    this( mediaType, htmlRenderer, new PlaintextHighlighter() );
  }

  /**
   * Constructs a context used by the {@link ProcessorFactory}.
   *
   * @param mediaType    The {@link MediaType} that directs transformations.
   * @param htmlRenderer Where to write the output HTML.
   * @param highlighter  Syntax highlighter that can apply styles to an editor.
   */
  public ProcessorContext(
      final MediaType mediaType,
      final HtmlRenderer htmlRenderer,
      final SyntaxHighlighter highlighter ) {
    assert mediaType != null;
    assert htmlRenderer != null;
    assert highlighter != null;

    mMediaType = mediaType;
    mHtmlRenderer = htmlRenderer;
    mHighlighter = highlighter;
  }

  MediaType getMediaType() {
    return mMediaType;
  }

  HtmlRenderer getHtmlRenderer() {
    return mHtmlRenderer;
  }

  SyntaxHighlighter getSyntaxHighlighter() {
    return mHighlighter;
  }
}
